@@ -4,8 +4,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kdf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpf ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ktuberling ; rm -rf common )
@@ -80,8 +78,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kcron ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdict ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kedit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kfind ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kiten ; rm -rf common )
